JwtAuthStorage class

Constructors

JwtAuthStorage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storage → FlutterSecureStorage
final

Methods

deleteJwtToken() → Future<void>
getJwtToken() → Future<JwtToken?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveJwtToken(JwtToken jwtToken) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

jwtTokenKeyStorage → const String