JwtAuthenticationRepository class

Constructors

JwtAuthenticationRepository({required JwtAuthConfig config, JwtAuthApiClient? jwtAuthApiClient})

Properties

hashCode → int
The hash code for this object.
no setterinherited
jwtToken → JwtToken?
no setter
jwtTokenStream → Stream<JwtToken?>
no setter
refreshUri ↔ Uri
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusStream → Stream<JwtAuthenticationStatus>
no setter
tokenUri ↔ Uri
getter/setter pair

Methods

dispose() → void
initialize() → Future<void>
login(String username, String password) → Future<JwtToken>
logout() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken() → Future<JwtToken>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited