JwtResponseError class

Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

JwtResponseError({required bool isSuccess, required String message, required String? stacktrace})
JwtResponseError.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSuccess → bool
final
isUnhautorized → bool
no setter
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stacktrace → String?
final
statusCode ↔ int?
getter/setter pair
statusMessage ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

deserialize(String json) → JwtResponseError
serialize(JwtResponseError model) → String