JwtToken class

Annotations
  • @JsonSerializable.new()

Constructors

JwtToken({required String username, required String accessToken, required int expiresAt, required String refreshToken, required int refreshTokenExpiresAt})
const
JwtToken.fromJson(Map<String, dynamic> json)
factory

Properties

accessToken → String
final
expiresAt → int
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
refreshToken → String
final
refreshTokenExpiresAt → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
username → String
final

Methods

isAccessTokenExpired() → bool
isRefreshTokenExpired() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

deserialize(String json) → JwtToken
serialize(JwtToken model) → String